@@ -6,12 +6,12 @@ require 'feedparser/html2text-parser'
 class String
   # is this text HTML ? search for tags. used by String#text2html
   def html?
-    return (self =~ /<p>/) || (self =~ /<\/p>/) || (self =~ /<br>/) || (self =~ /<br\s*(\/)?\s*>/) || (self =~ /<\/a>/) || (self =~ /<img.*>/)
+    return (self =~ /<p>/i) || (self =~ /<\/p>/i) || (self =~ /<br>/i) || (self =~ /<br\s*(\/)?\s*>/i) || (self =~ /<\/a>/i) || (self =~ /<img.*>/i)
   end
 
   # returns true if the text contains escaped HTML (with HTML entities). used by String#text2html
   def escaped_html?
-    return (self =~ /&lt;img src=/) || (self =~ /&lt;a href=/) || (self =~ /&lt;br(\/| \/|)&gt;/) || (self =~ /&lt;p&gt;/)
+    return (self =~ /&lt;img src=/i) || (self =~ /&lt;a href=/i) || (self =~ /&lt;br(\/| \/|)&gt;/i) || (self =~ /&lt;p&gt;/i)
   end
 
   def escape_html
@@ -24,6 +24,7 @@ class String
 MY_ENTITIES = {}
 FeedParser::HTML2TextParser::entities.each do |k, v|
   MY_ENTITIES["&#{k};"] = [v].pack('U*')
+  MY_ENTITIES["&##{v};"] = [v].pack('U*')
 end
 
   # un-escape HTML in the text. used by String#text2html
@@ -38,9 +39,20 @@ end
   # convert text to HTML
   def text2html(feed)
     text = self.clone
-    if text.html?
+    realhtml = text.html?
+    eschtml = text.escaped_html?
+    # fix for RSS feeds with both real and escaped html (crazy!):
+    # we take the first one
+    if (realhtml && eschtml)
+      if (realhtml < eschtml)
+        eschtml = nil
+      else
+        realhtml = nil
+      end
+    end
+    if realhtml
       # do nothing
-    elsif text.escaped_html?
+    elsif eschtml
       text = text.unescape_html
     else
       # paragraphs
