@@ -19,6 +19,7 @@ class ParserTest < Test::Unit::TestCase
     allok = true
     Dir.foreach(SRCDIR) do |f|
       next if f !~ /.xml$/
+      next if ENV['SOURCE'] != nil and ENV['SOURCE'] != f
       puts "Checking #{f}"
       str = File::read(SRCDIR + '/' + f)
       chan = FeedParser::Feed::new(str)
@@ -29,7 +30,9 @@ class ParserTest < Test::Unit::TestCase
           File::open(DSTDIR + '/' + f.gsub(/.xml$/, '.output.new'), "w") do |fd|
             fd.print(chanstr)
           end
-          puts "Test failed for #{f}. Try diff -u #{DSTDIR + '/' + f.gsub(/.xml$/, '.output')}{,.new}"
+          puts "Test failed for #{f}."
+          puts "  Check: diff -u #{DSTDIR + '/' + f.gsub(/.xml$/, '.output')}{,.new}"
+          puts "  Commit: mv -f #{DSTDIR + '/' + f.gsub(/.xml$/, '.output')}{.new,}"
           allok = false
         end
       else
